@@ -606,7 +606,7 @@
          : "=m" (c),  "=m" (d), "=m" (s)        \
          : "m" (s), "m" (d), "m" (c), "m" (b)   \
          : "r0", "r1", "r2", "r3", "r4", "r5",  \
-           "r6", "r7", "r8", "r9"               \
+           "r6", "r7", "r8", "r9", "cc"         \
          );
 
 #else
@@ -640,7 +640,7 @@
          : "=m" (c),  "=m" (d), "=m" (s)        \
          : "m" (s), "m" (d), "m" (c), "m" (b)   \
          : "r0", "r1", "r2", "r3", "r4", "r5",  \
-           "r6", "r7"                           \
+           "r6", "r7", "cc"                     \
          );
 
 #endif /* Thumb */
