@@ -49,6 +49,7 @@
 #endif
 #ifdef ENABLE_SSL
 #include "ssl.h"
+#include "polarssl/version.h"
 #endif
 #ifdef ENABLE_CACHE
 #include "cache.h"
@@ -101,7 +102,7 @@ char *version_string = "Hiawatha v"VERSION
 	", reverse proxy"
 #endif
 #ifdef ENABLE_SSL
-	", SSL"
+	", SSL ("POLARSSL_VERSION_STRING")"
 #endif
 #ifdef ENABLE_TOMAHAWK
 	", Tomahawk"
